home | help
GMX-XPM2PS(1)			     GROMACS			   GMX-XPM2PS(1)

NAME
     gmx-xpm2ps - Convert XPM (XPixelMap) matrices to postscript or XPM

SYNOPSIS
	gmx xpm2ps [-f [<.xpm>]] [-f2 [<.xpm>]] [-di [<.m2p>]] [-do [<.m2p>]]
		   [-o [<.eps>]] [-xpm [<.xpm>]] [-[no]w] [-[no]frame]
		   [-title <enum>] [-[no]yonce] [-legend <enum>]
		   [-diag <enum>] [-size <real>] [-bx <real>] [-by <real>]
		   [-rainbow <enum>] [-gradient <vector>] [-skip <int>]
		   [-[no]zeroline] [-legoffset <int>] [-combine <enum>]
		   [-cmin <real>] [-cmax <real>]

DESCRIPTION
     gmx  xpm2ps  makes a beautiful color plot of an XPixelMap file.  Labels and
     axis can be displayed, when they are supplied in the correct matrix format.
     Matrix data may be generated by programs such as gmx rms or gmx mdmat.

     Parameters are set in the .m2p file optionally supplied with  -di.  Reason-
     able  defaults  are  provided. Settings for the y-axis default to those for
     the x-axis. Font names have a defaulting hierarchy:  titlefont  ->  legend-
     font; titlefont -> (xfont -> yfont -> ytickfont) -> xtickfont, e.g. setting
     titlefont	sets  all  fonts, setting xfont sets yfont, ytickfont and xtick-
     font.

     When no .m2p file is supplied, many settings are taken  from  command  line
     options.  The  most  important  option is -size, which sets the size of the
     whole matrix in postscript units.	This option can be overridden  with  the
     -bx  and  -by  options (and the corresponding parameters in the .m2p file),
     which set the size of a single matrix element.

     With -f2 a second matrix file can be supplied. Both matrix  files	will  be
     read  simultaneously and the upper left half of the first one (-f) is plot-
     ted together with the lower right half of the second one (-f2). The  diago-
     nal will contain values from the matrix file selected with -diag.	Plotting
     of  the  diagonal	values	can be suppressed altogether by setting -diag to
     none.  In this case, a new color map will be generated with a red	gradient
     for negative numbers and a blue for positive.  If the color coding and leg-
     end  labels  of  both  matrices are identical, only one legend will be dis-
     played, else two separate legends are displayed.  With -combine, an  alter-
     native  operation can be selected to combine the matrices. The output range
     is automatically set to the actual range of the combined matrix.  This  can
     be overridden with -cmin and -cmax.

     -title  can  be set to none to suppress the title, or to ylabel to show the
     title in the Y-label position (alongside the y-axis).

     With the -rainbow option, dull grayscale matrices can be  turned  into  at-
     tractive color pictures.

     Merged  or  rainbowed matrices can be written to an XPixelMap file with the
     -xpm option.

OPTIONS
     Options to specify input files:

     -f [<.xpm>] (root.xpm)
	    X PixMap compatible matrix file

     -f2 [<.xpm>] (root2.xpm) (Optional)
	    X PixMap compatible matrix file

     -di [<.m2p>] (ps.m2p) (Optional, Library)
	    Input file for mat2ps

     Options to specify output files:

     -do [<.m2p>] (out.m2p) (Optional)
	    Input file for mat2ps

     -o [<.eps>] (plot.eps) (Optional)
	    Encapsulated PostScript (tm) file

     -xpm [<.xpm>] (root.xpm) (Optional)
	    X PixMap compatible matrix file

     Other options:

     -[no]w (no)
	    View output .xvg, .xpm, .eps and .pdb files

     -[no]frame (yes)
	    Display frame, ticks, labels, title and legend

     -title <enum> (top)
	    Show title at: top, once, ylabel, none

     -[no]yonce (no)
	    Show y-label only once

     -legend <enum> (both)
	    Show legend: both, first, second, none

     -diag <enum> (first)
	    Diagonal: first, second, none

     -size <real> (400)
	    Horizontal size of the matrix in ps units

     -bx <real> (0)
	    Element x-size, overrides -size (also y-size when -by is not set)

     -by <real> (0)
	    Element y-size

     -rainbow <enum> (no)
	    Rainbow colors, convert white to: no, blue, red

     -gradient <vector> (0 0 0)
	    Re-scale colormap to a smooth gradient from white {1,1,1} to {r,g,b}

     -skip <int> (1)
	    only write out every nr-th row and column

     -[no]zeroline (no)
	    insert line in .xpm matrix where axis label is zero

     -legoffset <int> (0)
	    Skip first N colors from .xpm file for the legend

     -combine <enum> (halves)
	    Combine two matrices: halves, add, sub, mult, div

     -cmin <real> (0)
	    Minimum for combination output

     -cmax <real> (0)
	    Maximum for combination output

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			   GMX-XPM2PS(1)

home | help